package com.srs.comprehensive.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.comprehensive.domain.CphCardersStudent;

/**
 * 学生干部关联Mapper接口
 *
 * @author srs
 * @date 2023-09-15
 */
public interface CphCardersStudentMapper extends BaseMapper<CphCardersStudent> {
    /**
     * 查询学生干部关联
     *
     * @param id 学生干部关联主键
     * @return 学生干部关联
     */
    public CphCardersStudent selectCphCardersStudentById(Long id);

    /**
     * 查询学生干部关联列表
     *
     * @param cphCardersStudent 学生干部关联
     * @return 学生干部关联集合
     */
    List<CphCardersStudent> selectCphCardersStudentList(CphCardersStudent cphCardersStudent);

    /**
     * 新增学生干部关联
     *
     * @param cphCardersStudent 学生干部关联
     * @return 结果
     */
    int insertCphCardersStudent(CphCardersStudent cphCardersStudent);

    /**
     * 修改学生干部关联
     *
     * @param cphCardersStudent 学生干部关联
     * @return 结果
     */
    int updateCphCardersStudent(CphCardersStudent cphCardersStudent);

    /**
     * 删除学生干部关联
     *
     * @param id 学生干部关联主键
     * @return 结果
     */
    int deleteCphCardersStudentById(Long id);

    /**
     * 批量删除学生干部关联
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCphCardersStudentByIds(Long[] ids);
}
